# Tweetcal: Convert a tweet stream to ics calendar
# Copyright (c) 2014-2015 Neil Freeman
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
import argparse
from . import tweetcal, read_archive

def main():
    parser = argparse.ArgumentParser(description='Grab tweets into an ics file.')

    subparsers = parser.add_subparsers()

    archiver = subparsers.add_parser('archive')
    archiver.set_defaults(func=read_archive.to_cal_args)
    archiver.add_argument('path', type=str, metavar='PATH', help='Path to archive file')
    archiver.add_argument('output', type=str, metavar='OUTPUT', help='Path to output file')
    archiver.add_argument('-n', '--dry-run', action='store_true', help="Don't actually run.")
    archiver.add_argument('-v', '--verbose', action='store_true', help="Log to stdout.")
    archiver.add_argument('-x', '--max-id', type=float, default=float('inf'), help='Only save tweets older than this id')
    archiver.add_argument('-s', '--since-id', type=int, default=1, help='Only save tweets newer than this id')

    load = subparsers.add_parser('stream')
    load.set_defaults(func=tweetcal.tweetcal)
    load.add_argument('--config', type=str, help='Config file.')
    load.add_argument('--user', type=str, help='User to grab. Must be in config file.')
    load.add_argument('-x', '--max', type=int, help='Maximum number of tweets to download default: 100.')
    load.add_argument('-n', '--dry-run', action='store_true', help="Don't actually run.")
    load.add_argument('-v', '--verbose', action='store_true', help="Log to stdout.")

    args = parser.parse_args()

    args.func(args)

if __name__ == '__main__':
    main()



# Tweetcal: Convert a tweet stream to ics calendar
# Copyright (c) 2014-2015 Neil Freeman
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
import re
import time
import logging
from datetime import datetime
from email.utils import formatdate
from tweepy import API, Status
from twitter_bot_utils import archive
from . import tweetcal

iso8601 = re.compile(r"(\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}) ?(\+\d{4})?")


def fix_timeformat(string):
    match = iso8601.match(string)

    if match:
        dt = datetime.strptime(match.groups()[0], "%Y-%m-%d %H:%M:%S")
        string = formatdate(time.mktime(dt.timetuple()))

    return string


def read_as_status(archivepath, since_id=None, max_id=None):
    api = API()

    since_id = since_id or 1
    max_id = max_id or float("inf")

    for tweet in archive.read_json(archivepath):

        tweet['created_at'] = fix_timeformat(tweet['created_at'])

        if tweet.get('retweeted_status'):
            tweet['retweeted_status']['created_at'] = fix_timeformat(tweet['retweeted_status']['created_at'])

        i = int(tweet['id'])

        if i > since_id and i < max_id:
            yield Status.parse(api, tweet)


def to_cal(archivepath, output, dry_run=None, **kwargs):
    '''Read an archive into a calendar'''
    logger = logging.getLogger('tweetcal')

    max_id = kwargs.get('max_id', float('inf'))
    since_id = kwargs.get('since_id', 1)

    generator = lambda x: read_as_status(archivepath, max_id=max_id, since_id=since_id)

    cal = tweetcal.new_calendar()

    logger.info('Reading archive.')
    tweetcal.add_to_calendar(cal, generator)

    logger.info('Added {} tweets to calendar.'.format(len(cal)))

    if not dry_run:
        tweetcal.write_calendar(cal, output)
        logger.info('Wrote {}.'.format(output))

def to_cal_args(args):
    tweetcal.setup_logger(args.verbose)
    to_cal(args.path, args.output, args.dry_run, since_id=args.since_id, max_id=args.max_id)



# Tweetcal: Convert a tweet stream to ics calendar
# Copyright (c) 2014-2015 Neil Freeman
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
from setuptools import setup

try:
    readme = open('./README.rst', 'r').read()

except IOError:
    try:
        readme = open('./README.md', 'r').read()
    except IOError:
        readme = ''

setup(
    name='tweetcal',

    version='0.4.6',

    description='Convert a tweet stream to ics calendar',

    long_description=readme,

    url='http://github.com/fitnr/tweetcal',

    author='Neil Freeman',

    author_email='contact@fakeisthenewreal.org',

    license='GPL-3.0',

    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Operating System :: OS Independent',
    ],

    packages=['tweetcal'],

    entry_points={
        'console_scripts': [
            'tweetcal=tweetcal.command:main',
        ],
    },

    test_suite='tests',

    use_2to3=True,

    install_requires=[
        'icalendar>=3.8.4,<4.0',
        'tweepy>=3.1.0,<4.0',
        'twitter_bot_utils >=0.6.2, <1'
    ]
)



# Tweetcal: Convert a tweet stream to ics calendar
# Copyright (c) 2014 Neil Freeman
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
from . import tweetcal, read_archive

__author__ = 'Neil Freeman'
__license__ = 'GPL-3.0'
__all__ = ['tweetcal']
__version__ = '0.4.5.post1'
